# Amplo - AutoML (for Machine Data)
[![image](https://img.shields.io/pypi/v/amplo.svg)](https://pypi.python.org/pypi/amplo)
[![image](https://travis-ci.com/nielsuit227/AutoML.svg?token=CnXXBmk9Wj2AwwF6svhz&branch=main)](https://travis-ci.com/nielsuit227/AutoML.svg?token=CnXXBmk9Wj2AwwF6svhz&branch=main)
[![PyPI - License](https://img.shields.io/pypi/l/virtualenv?style=flat-square)](https://opensource.org/licenses/MIT)
[![](https://img.shields.io/badge/python-%3E%3D3.6%2C%3C4.0-blue)](https://pypi.org/project/amplo/)

Welcome to the Automated Machine Learning package `Amplo`. Amplo's AutoML is designed specifically for machine data and 
works very well with tabular time series data (especially unbalanced classification!).

Though this is a standalone Python package, Amplo's AutoML is also available on Amplo's ML Developer Platform. 
With a graphical user interface and various data connectors, it is the ideal place for service engineers to get started 
on Predictive Maintenance development. 

Amplo's AutoML Pipeline contains the entire Machine Learning development cycle, including exploratory data analysis, 
data cleaning, feature extraction, feature selection, model selection, hyper parameter optimization, stacking, 
version control, production-ready models and documentation. 

# Downloading Amplo
The easiest way is to install our Python package through [PyPi](https://pypi.org/project/amplo/):
```commandline
pip install Amplo
```

# 2. Amplo AutoML Features

